<?php

/**
 * CelebrioNews default
 *
 * @copyright  Copyright (c) 2011 Celebrio Software
 * @package    CelebrioNews
 */

namespace ApplicationsModule\BooksModule;

use ApplicationsModule\BasePresenter;
use Celebrio\Util\RequestBuilder;

/**
 * @author Pavel
 */
class DefaultPresenter extends BasePresenter {

    private $bm;

    public function startup() {
        parent::startup();
        $this->bm = new BookManager;
    }

    public function beforeRender() {
        parent::beforeRender();
        $this->getTemplate()->app_name = _("Books");
    }

    /**
     * Renders the main news menu, containing the news categories
     * 
     * @return void
     */
    public function renderDefault() {
        $this->getTemplate()->title = _("Books");
        $this->template->authors = $this->bm->getAuthors(\Celebrio\Util\Localization::getLang());
    }

    public function renderAuthor($id) {
        $this->template->books = $this->bm->getBooksByAuthor($id, \Celebrio\Util\Localization::getLang());
        $this->template->action_link = $this->link("Default:default");
    }

    public function renderReader($id) {
        $this->getTemplate()->app_from_top = true;
        $book = $this->bm->getBook($id);
        $this->bm->addLast($book, $this->getUser()->getIdentity()->id);
        $authorId = $book->authors[0]->id;
        $this->template->book = $book;
        $this->template->queryPath = RequestBuilder::getBasePath() . "app/books/object?location=" . $book->url;
        $this->template->action_link = $this->link("Default:author", array("id" => $authorId));
    }

    public function renderMag($id) {
        $this->getTemplate()->app_from_top = true;
        $url = "http://localhost/celebrio/document_root/epubs/_casopis";
        $this->template->queryPath = RequestBuilder::getBasePath() . "app/books/object?location=" . $url;
        $this->view = "reader";
    }

    public function renderObject($location) {
        $ebook = new \Readepub($location);
        $this->template->ebook = $ebook;
        $this->template->location = $location;
        $this->getHttpResponse()->addHeader("Content-Type", "text/javascript; charset=utf-8");
    }

    public function renderChapter($location, $componentId) {
        $this->getHttpResponse()->setContentType("text/html", "utf-8");
        $ebook = new \Readepub($location);
        $data = file_get_contents($location . "/" . $ebook->opfDir . "/" . $componentId);
        $url = $location . "/" . $ebook->opfDir . "/" . $componentId;
        $suburl = substr($url, 0, strrpos($url, "/") + 1);
        $data = str_ireplace("<head>", "<head>\n<base href='$suburl' /><meta http-equiv='Content-Type' content='text/html; charset=utf-8' />", $data);

        $this->template->data = $data;
    }

    public function renderLast() {
        $this->template->books = $this->bm->lastRead($this->getUser()->getIdentity()->id);
        $this->template->action_link = $this->link("Default:default");
    }

}